==> knative-model-6.8.0-sources.jar: io/fabric8/knative/internal/pkg/apis/duck/v1alpha1/LegacyTargetableFluent.java <==
package io.fabric8.knative.internal.pkg.apis.duck.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LegacyTargetableFluent<A extends LegacyTargetableFluent<A>> extends BaseFluent<A>{
  public LegacyTargetableFluent() {
  }
  public LegacyTargetableFluent(LegacyTargetable instance) {
    instance = (instance != null ? instance : new LegacyTargetable());

    if (instance != null) {
      this.withDomainInternal(instance.getDomainInternal());
      this.withDomainInternal(instance.getDomainInternal());
    }
  }
  private String domainInternal;
  public String getDomainInternal() {
    return this.domainInternal;
  }
  public A withDomainInternal(String domainInternal) {
    this.domainInternal=domainInternal; return (A) this;
  }
  public boolean hasDomainInternal() {
    return this.domainInternal != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LegacyTargetableFluent that = (LegacyTargetableFluent) o;
    if (!java.util.Objects.equals(domainInternal, that.domainInternal)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(domainInternal,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (domainInternal != null) { sb.append("domainInternal:"); sb.append(domainInternal); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> knative-model-6.9.0-sources.jar: io/fabric8/knative/internal/pkg/apis/duck/v1alpha1/LegacyTargetableFluent.java <==
package io.fabric8.knative.internal.pkg.apis.duck.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class LegacyTargetableFluent<A extends LegacyTargetableFluent<A>> extends BaseFluent<A>{
  public LegacyTargetableFluent() {
  }
  
  public LegacyTargetableFluent(LegacyTargetable instance) {
    this.copyInstance(instance);
  }
  private String domainInternal;
  
  protected void copyInstance(LegacyTargetable instance) {
    instance = (instance != null ? instance : new LegacyTargetable());
  
    if (instance != null) {
        this.withDomainInternal(instance.getDomainInternal());
        this.withDomainInternal(instance.getDomainInternal());
      }
  }
  
  public String getDomainInternal() {
    return this.domainInternal;
  }
  
  public A withDomainInternal(String domainInternal) {
    this.domainInternal=domainInternal; return (A) this;
  }
  
  public boolean hasDomainInternal() {
    return this.domainInternal != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LegacyTargetableFluent that = (LegacyTargetableFluent) o;
    if (!java.util.Objects.equals(domainInternal, that.domainInternal)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(domainInternal,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (domainInternal != null) { sb.append("domainInternal:"); sb.append(domainInternal); }
    sb.append("}");
    return sb.toString();
  }
  

}
